"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugin = void 0;
const semver_match_1 = __importDefault(require("semver-match"));
const package_utils_1 = require("@monorepo-utils/package-utils");
exports.plugin = (options) => {
    // getPackages support "workspaces" and lerna.json
    const monorepoPackages = package_utils_1.getPackages(options.rootDir);
    return {
        supports() {
            return monorepoPackages.length > 0;
        },
        getAllPackages() {
            return monorepoPackages;
        },
        getDependencies(packageJSON) {
            var _a, _b;
            const dependencies = Object.entries((_a = packageJSON.dependencies) !== null && _a !== void 0 ? _a : {});
            const devDependencies = Object.entries((_b = packageJSON.devDependencies) !== null && _b !== void 0 ? _b : {});
            return [...dependencies, ...devDependencies].map((dep) => {
                return {
                    name: dep[0],
                    version: dep[1]
                };
            });
        },
        resolve({ name, version }) {
            const matchPkg = monorepoPackages.find((info) => {
                if (info.packageJSON.name !== name)
                    return false;
                if (version.startsWith("workspace:"))
                    return true;
                return !!semver_match_1.default(version, [info.packageJSON.version]);
            });
            if (!matchPkg) {
                return null;
            }
            return matchPkg.location;
        }
    };
};
//# sourceMappingURL=workspaces.js.map